@@ -21,7 +21,7 @@ use Video::Pattern;
 Readonly::Scalar our $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -176,6 +176,8 @@ Video::Generator - Perl class for video generation.
  Possible suffixes are:
  - ms for milisendons.
  - s for seconds.
+ - min for minute.
+ - h for hour.
  Default value is 10000 (10s).
 
 =item * C<fps>
@@ -247,7 +249,7 @@ Video::Generator - Perl class for video generation.
          From Image::Random:
                  Image type '%s' doesn't supported.
          From Video::Pattern:
-                 Parameter 'duration' must be numeric value or numeric value with time suffix (s/ms).
+                 Parameter 'duration' must be numeric value or numeric value with time suffix.
                  Parameter 'fps' must be numeric value.
 
  create():
@@ -373,6 +375,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
